@@ -63,6 +63,27 @@ class security_manager {
         } else {
             $this->db = new SQLite3($this->db_path);
             $this->db->busyTimeout(6000);
+            
+            // Check if successful_logins table exists, create if not (for existing databases)
+            $this->ensure_successful_logins_table();
+        }
+    }
+    
+    private function ensure_successful_logins_table() {
+        // Check if successful_logins table exists
+        $result = $this->db->query("SELECT name FROM sqlite_master WHERE type='table' AND name='successful_logins'");
+        if (!$result->fetchArray()) {
+            // Create the table and indexes
+            $this->db->exec('CREATE TABLE successful_logins (
+                id INTEGER PRIMARY KEY AUTOINCREMENT,
+                username TEXT NOT NULL,
+                ip_address TEXT NOT NULL,
+                login_time INTEGER NOT NULL,
+                user_agent TEXT
+            )');
+            
+            $this->db->exec('CREATE INDEX idx_successful_logins_user ON successful_logins(username)');
+            $this->db->exec('CREATE INDEX idx_successful_logins_time ON successful_logins(login_time)');
         }
     }
     
